==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/pl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Współdzielenie między serwerami nie jest uruchomione na tym serwerze",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie można zalogować do zdalnego zasobu, hasło może być niepoprawne",
    "Storage not valid" : "Zasób nie jest prawidłowy",
    "Couldn't add remote share" : "Nie można dodać zdalnego folderu",
    "Shared with you" : "Współdzielony z Tobą",
    "Shared with others" : "Współdzielony z innymi",
    "Shared by link" : "Współdzielony linkiem",
    "Uploading..." : "Wgrywanie....",
    "Nothing shared with you yet" : "Nie masz jeszcze nic udostępnionego",
    "Files and folders others share with you will show up here" : "Pliki i foldery udostępnione Tobie przez innych wyświetlą się tutaj",
    "Nothing shared yet" : "Jeszcze nic nie udostępniono",
    "Files and folders you share will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "No shared links" : "Brak udostępnionych odnośników",
    "Files and folders you share by link will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać udział zdalny {name} od {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "You can upload into this folder" : "Możesz przesyłać do tego folderu",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nie znaleziono instalacji ownCloud (w wersji 7 lub nowszej) na {remote}",
    "Invalid ownCloud url" : "Błędny adres URL",
    "Share" : "Udostępnij",
    "No expiration date set" : "Data wygaśnięcia nie została ustawiona",
    "Shared by" : "Udostępniane przez",
    "Sharing" : "Udostępnianie",
    "Share API is disabled" : "API udostępniania jest wyłączone",
    "Wrong share ID, share doesn't exist" : "Nieprawidłowe ID zasobu, zasób nie istnieje",
    "Could not delete share" : "Nie można usunąć zasobu",
    "Please specify a file or folder path" : "Wskaż ścieżkę pliku lub folderu",
    "Wrong path, file/folder doesn't exist" : "Nieprawidłowa ścieżka, plik/folder nie istnieje",
    "Cannot remove all permissions" : "Nie można usunąć wszystkich uprawnień",
    "Please specify a valid user" : "Proszę określ prawidłowego użytkownika ",
    "Group sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
    "Please specify a valid group" : "Określ prawidłową grupę",
    "Public link sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
    "Public upload disabled by the administrator" : "Publiczne wczytywanie zostało zablokowane przez twojego administratora",
    "Public upload is only possible for publicly shared folders" : "Publiczne wczytywanie jest możliwe wyłącznie do katalogów publicznych",
    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, właściwy format daty: RRRR-MM-DD",
    "Unknown share type" : "Nieznany typ udziału",
    "Not a directory" : "To nie jest katalog",
    "Could not lock path" : "Nie można zablokować ścieżki ",
    "Can't change permissions for public share links" : "Nie można zmienić uprawnień dla publicznych linków",
    "Wrong or no update parameter given" : "Przekazano pusty lub nieprawidłowy parametr",
    "Cannot increase permissions" : "Nie można podnieść uprawnień",
    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
    "%2$s removed the share for %1$s" : "%2$s usunął udział dla %1$s",
    "Shared via public link" : "Udostępniono poprzez publiczny odnośnik",
    "Removed public link" : "Usunięto publiczny odnośnik",
    "Public link expired" : "Publiczny odnośnik wygasł",
    "Shares" : "Udziały",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Password" : "Hasło",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Name" : "Nazwa",
    "Share time" : "Czas współdzielenia",
    "Expiration date" : "Data wygaśnięcia",
    "Sorry, this link doesn’t seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "Reasons might be:" : "Możliwe powody:",
    "the item was removed" : "element został usunięty",
    "the link expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "For more info, please ask the person who sent this link." : "Aby uzyskać więcej informacji proszę poprosić osobę, która wysłał ten link.",
    "Add to your ownCloud" : "Dodaj do twojego ownCloud",
    "Download" : "Pobierz",
    "Download %s" : "Pobierz %s",
    "Direct link" : "Bezpośredni link"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/pl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Współdzielenie między serwerami nie jest uruchomione na tym serwerze",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie można zalogować do zdalnego zasobu, hasło może być niepoprawne",
    "Storage not valid" : "Zasób nie jest prawidłowy",
    "Couldn't add remote share" : "Nie można dodać zdalnego folderu",
    "Shared with you" : "Współdzielony z Tobą",
    "Shared with others" : "Współdzielony z innymi",
    "Shared by link" : "Współdzielony linkiem",
    "Uploading..." : "Wgrywanie....",
    "Nothing shared with you yet" : "Nie masz jeszcze nic udostępnionego",
    "Files and folders others share with you will show up here" : "Pliki i foldery udostępnione Tobie przez innych wyświetlą się tutaj",
    "Nothing shared yet" : "Jeszcze nic nie udostępniono",
    "Files and folders you share will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "No shared links" : "Brak udostępnionych odnośników",
    "Files and folders you share by link will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać udział zdalny {name} od {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "You can upload into this folder" : "Możesz przesyłać do tego folderu",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nie znaleziono instalacji ownCloud (w wersji 7 lub nowszej) na {remote}",
    "Invalid ownCloud url" : "Błędny adres URL",
    "Share" : "Udostępnij",
    "No expiration date set" : "Data wygaśnięcia nie została ustawiona",
    "Shared by" : "Udostępniane przez",
    "Sharing" : "Udostępnianie",
    "Share API is disabled" : "API udostępniania jest wyłączone",
    "Wrong share ID, share doesn't exist" : "Nieprawidłowe ID zasobu, zasób nie istnieje",
    "Could not delete share" : "Nie można usunąć zasobu",
    "Please specify a file or folder path" : "Wskaż ścieżkę pliku lub folderu",
    "Wrong path, file/folder doesn't exist" : "Nieprawidłowa ścieżka, plik/folder nie istnieje",
    "Cannot remove all permissions" : "Nie można usunąć wszystkich uprawnień",
    "Please specify a valid user" : "Proszę określ prawidłowego użytkownika ",
    "Group sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
    "Please specify a valid group" : "Określ prawidłową grupę",
    "Public link sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
    "Public upload disabled by the administrator" : "Publiczne wczytywanie zostało zablokowane przez twojego administratora",
    "Public upload is only possible for publicly shared folders" : "Publiczne wczytywanie jest możliwe wyłącznie do katalogów publicznych",
    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, właściwy format daty: RRRR-MM-DD",
    "Unknown share type" : "Nieznany typ udziału",
    "Not a directory" : "To nie jest katalog",
    "Could not lock path" : "Nie można zablokować ścieżki ",
    "Can't change permissions for public share links" : "Nie można zmienić uprawnień dla publicznych linków",
    "Wrong or no update parameter given" : "Przekazano pusty lub nieprawidłowy parametr",
    "Cannot increase permissions" : "Nie można podnieść uprawnień",
    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
    "%2$s removed the share for %1$s" : "%2$s usunął udział dla %1$s",
    "Shared via public link" : "Udostępniono poprzez publiczny odnośnik",
    "Removed public link" : "Usunięto publiczny odnośnik",
    "Public link expired" : "Publiczny odnośnik wygasł",
    "Shares" : "Udziały",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Password" : "Hasło",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Name" : "Nazwa",
    "Share time" : "Czas współdzielenia",
    "Expiration date" : "Data wygaśnięcia",
    "Sorry, this link doesn’t seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "Reasons might be:" : "Możliwe powody:",
    "the item was removed" : "element został usunięty",
    "the link expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "For more info, please ask the person who sent this link." : "Aby uzyskać więcej informacji proszę poprosić osobę, która wysłał ten link.",
    "Add to your ownCloud" : "Dodaj do twojego ownCloud",
    "Download" : "Pobierz",
    "Download %s" : "Pobierz %s",
    "Direct link" : "Bezpośredni link",
    "Downloaded via public link" : "Pobrano poprzez odnośnik publiczny",
    "Pending" : "Oczekujące",
    "Accept" : "Akceptuj",
    "Decline" : "Odmów",
    "Declined" : "Nie zaakceptowane",
    "Uploaded files" : "Wysłane pliki",
    "An error occurred while updating share state: {message}" : "Błąd podczas aktualizacji stanu udziału: {message}",
    "Accept Share" : "Akceptuj współdzielenie",
    "Decline Share" : "Odrzuć współdzielenie",
    "The group is blacklisted for sharing" : "Grupa jest na czarnej liście współdzielenia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
